@@ -1,9 +1,9 @@
 use strict;
 use warnings;
 
-package Dist::Zilla::Plugin::Run; # git description: 0.031-2-g513c77a
+package Dist::Zilla::Plugin::Run; # git description: 0.032-7-gb94d17f
 # ABSTRACT: Run external commands and code at specific phases of Dist::Zilla
-$Dist::Zilla::Plugin::Run::VERSION = '0.032';
+our $VERSION = '0.033';
 #pod =head1 SYNOPSIS
 #pod
 #pod   [Run::AfterBuild]
@@ -133,7 +133,7 @@ Dist::Zilla::Plugin::Run - Run external commands and code at specific phases of
 
 =head1 VERSION
 
-version 0.032
+version 0.033
 
 =head1 SYNOPSIS
 
