@@ -3,7 +3,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::Run::AfterBuild;
 # ABSTRACT: execute a command of the distribution after build
-$Dist::Zilla::Plugin::Run::AfterBuild::VERSION = '0.032';
+our $VERSION = '0.033';
 use Moose;
 with qw(
   Dist::Zilla::Role::AfterBuild
@@ -14,7 +14,7 @@ use namespace::autoclean;
 
 sub after_build {
   my ($self, $param) = @_;
-  $self->call_script({
+  $self->_call_script({
     dir =>  $param->{ build_root },
     pos => [$param->{ build_root }, sub { $self->zilla->version }]
   });
@@ -57,7 +57,7 @@ Dist::Zilla::Plugin::Run::AfterBuild - execute a command of the distribution aft
 
 =head1 VERSION
 
-version 0.032
+version 0.033
 
 =head1 SYNOPSIS
 
