@@ -3,7 +3,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::Run::AfterRelease;
 # ABSTRACT: execute a command of the distribution after release
-$Dist::Zilla::Plugin::Run::AfterRelease::VERSION = '0.032';
+our $VERSION = '0.033';
 use Moose;
 with qw(
   Dist::Zilla::Role::AfterRelease
@@ -14,7 +14,7 @@ use namespace::autoclean;
 
 sub after_release {
   my ( $self, $archive ) = @_;
-  $self->call_script({
+  $self->_call_script({
     archive =>  $archive,
     pos     => [$archive, sub { $self->zilla->version }]
   });
@@ -61,7 +61,7 @@ Dist::Zilla::Plugin::Run::AfterRelease - execute a command of the distribution a
 
 =head1 VERSION
 
-version 0.032
+version 0.033
 
 =head1 SYNOPSIS
 
