@@ -3,7 +3,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::Run::BeforeBuild;
 # ABSTRACT: execute a command of the distribution before build
-$Dist::Zilla::Plugin::Run::BeforeBuild::VERSION = '0.032';
+our $VERSION = '0.033';
 use Moose;
 with qw(
   Dist::Zilla::Role::BeforeBuild
@@ -14,7 +14,7 @@ use namespace::autoclean;
 
 sub before_build {
   my ($self) = @_;
-  $self->call_script({
+  $self->_call_script({
     pos => [sub { $self->zilla->version }]
   });
 }
@@ -55,7 +55,7 @@ Dist::Zilla::Plugin::Run::BeforeBuild - execute a command of the distribution be
 
 =head1 VERSION
 
-version 0.032
+version 0.033
 
 =head1 SYNOPSIS
 
