@@ -3,7 +3,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::Run::BeforeRelease;
 # ABSTRACT: execute a command of the distribution before release
-$Dist::Zilla::Plugin::Run::BeforeRelease::VERSION = '0.032';
+our $VERSION = '0.033';
 use Moose;
 with qw(
   Dist::Zilla::Role::BeforeRelease
@@ -14,7 +14,7 @@ use namespace::autoclean;
 
 sub before_release {
   my ( $self, $archive ) = @_;
-  $self->call_script({
+  $self->_call_script({
     archive =>  $archive,
     pos     => [$archive]
   });
@@ -60,7 +60,7 @@ Dist::Zilla::Plugin::Run::BeforeRelease - execute a command of the distribution
 
 =head1 VERSION
 
-version 0.032
+version 0.033
 
 =head1 SYNOPSIS
 
