@@ -3,7 +3,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::Run::Release;
 # ABSTRACT: execute a command of the distribution on release
-$Dist::Zilla::Plugin::Run::Release::VERSION = '0.032';
+our $VERSION = '0.033';
 use Moose;
 with qw(
   Dist::Zilla::Role::Releaser
@@ -14,7 +14,7 @@ use namespace::autoclean;
 
 sub release {
   my ( $self, $archive ) = @_;
-  $self->call_script({
+  $self->_call_script({
     archive =>  $archive,
     pos     => [$archive]
   });
@@ -62,7 +62,7 @@ Dist::Zilla::Plugin::Run::Release - execute a command of the distribution on rel
 
 =head1 VERSION
 
-version 0.032
+version 0.033
 
 =head1 SYNOPSIS
 
