@@ -2,8 +2,7 @@ use strict;
 use warnings;
 
 package Dist::Zilla::Plugin::Run::Role::Runner;
-# ABSTRACT: Role for the packages of Dist::Zilla::Plugin::Run
-$Dist::Zilla::Plugin::Run::Role::Runner::VERSION = '0.032';
+our $VERSION = '0.033';
 use Moose::Role;
 use namespace::autoclean;
 use File::Spec (); # core
@@ -96,18 +95,18 @@ around BUILDARGS => sub {
     return $built;
 };
 
-sub call_script {
+sub _call_script {
     my ( $self, $params ) = @_;
 
     foreach my $run_cmd (@{$self->run}) {
-        $self->run_cmd($run_cmd, $params);
+        $self->_run_cmd($run_cmd, $params);
     }
 
     my $is_trial = $self->zilla->is_trial ? 1 : 0;
 
     foreach my $run_cmd (@{$self->run_if_trial}) {
         if ($is_trial) {
-            $self->run_cmd($run_cmd, $params);
+            $self->_run_cmd($run_cmd, $params);
         } else {
             $self->log_debug([ 'not executing, because no trial: %s', $run_cmd ]);
         }
@@ -117,7 +116,7 @@ sub call_script {
         if ($is_trial) {
             $self->log_debug([ 'not executing, because trial: %s', $run_cmd ]);
         } else {
-            $self->run_cmd($run_cmd, $params);
+            $self->_run_cmd($run_cmd, $params);
         }
     }
 
@@ -125,7 +124,7 @@ sub call_script {
 
     foreach my $run_cmd (@{$self->run_if_release}) {
         if ($is_release) {
-            $self->run_cmd($run_cmd, $params);
+            $self->_run_cmd($run_cmd, $params);
         } else {
             $self->log_debug([ 'not executing, because no release: %s', $run_cmd ]);
         }
@@ -135,48 +134,59 @@ sub call_script {
         if ($is_release) {
             $self->log_debug([ 'not executing, because release: %s', $run_cmd ]);
         } else {
-            $self->run_cmd($run_cmd, $params);
+            $self->_run_cmd($run_cmd, $params);
         }
     }
 
     if (my @code = @{ $self->eval }) {
         my $code = join "\n", @code;
 
-        $self->eval_cmd($code, $params);
+        $self->_eval_cmd($code, $params);
     }
 }
 
-sub run_cmd {
-    my ( $self, $run_cmd, $params ) = @_;
-    if ($run_cmd) {
-        require IPC::Open3;  # core
+sub _run_cmd {
+    my ( $self, $run_cmd, $params, $dry_run ) = @_;
 
-        my $command = $self->build_formatter($params)->format($run_cmd);
-        $self->log("executing: $command");
+    if ($dry_run) {
+        $self->log_debug([ 'dry run, would run: %s', $run_cmd ]);
+        return;
+    }
 
-        # autoflush STDOUT so we can see command output right away
-        local $| = 1;
-        # combine stdout and stderr for ease of proxying through the logger
-        my $pid = IPC::Open3::open3(my ($in, $out), undef, $command);
-        while(defined(my $line = <$out>)){
-            chomp($line); # logger appends its own newline
-            $self->log($line);
-        }
-        # zombie repellent
-        waitpid($pid, 0);
+    return if not $run_cmd;
 
-        if (my $status = ($? >> 8)) {
-            my $method = $self->fatal_errors ? 'log_fatal' : 'log';
-            $self->$method("command exited with status $status ($?)");
-        }
-        else {
-            $self->log_debug('command executed successfully');
-        }
+    require IPC::Open3;  # core
+
+    my $command = $self->build_formatter($params)->format($run_cmd);
+    $self->log("executing: $command");
+
+    # autoflush STDOUT so we can see command output right away
+    local $| = 1;
+    # combine stdout and stderr for ease of proxying through the logger
+    my $pid = IPC::Open3::open3(my ($in, $out), undef, $command);
+    while(defined(my $line = <$out>)){
+        chomp($line); # logger appends its own newline
+        $self->log($line);
+    }
+    # zombie repellent
+    waitpid($pid, 0);
+
+    if (my $status = ($? >> 8)) {
+        my $method = $self->fatal_errors ? 'log_fatal' : 'log';
+        $self->$method("command exited with status $status ($?)");
+    }
+    else {
+        $self->log_debug('command executed successfully');
     }
 }
 
-sub eval_cmd {
-    my ( $self, $code, $params ) = @_;
+sub _eval_cmd {
+    my ( $self, $code, $params, $dry_run ) = @_;
+
+    if ($dry_run) {
+        $self->log_debug([ 'dry run, would evaluate: %s', $code ]);
+        return;
+    }
 
     $code = $self->build_formatter($params)->format($code);
     $self->log("evaluating: $code");
@@ -208,17 +218,17 @@ sub build_formatter {
     require String::Formatter;
     String::Formatter->VERSION(0.102082);
 
-    # stringify build directory
-    my $dir = $params->{dir} || $self->zilla->built_in;
-    $dir = $dir ? "$dir" : '';
-
     my $codes = {
         # not always available
         # explicitly pass a string (not an object) [rt-72008]
         a => defined $params->{archive} ? "$params->{archive}" : '',
 
         # build dir or mint dir
-        d => $dir,
+        d => sub {
+            # stringify build directory
+            my $dir = $params->{dir} || $self->zilla->built_in;
+            $dir ? "$dir" : '';
+        },
 
         # dist name
         n => sub { $self->zilla->name },
@@ -252,42 +262,5 @@ sub build_formatter {
 
 sub current_perl_path { $^X }
 
-#pod =head1 DESCRIPTION
-#pod
-#pod This is the base role for all the plugins L<Dist::Zilla::Plugin::Run> delivers. You don't need this.
-#pod
-#pod =cut
-
 1;
 # vim: set ts=4 sts=4 sw=4 expandtab smarttab:
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-Dist::Zilla::Plugin::Run::Role::Runner - Role for the packages of Dist::Zilla::Plugin::Run
-
-=head1 VERSION
-
-version 0.032
-
-=head1 DESCRIPTION
-
-This is the base role for all the plugins L<Dist::Zilla::Plugin::Run> delivers. You don't need this.
-
-=head1 AUTHOR
-
-Torsten Raudssus <torsten@raudss.us> L<https://raudss.us/>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2010 by L<Raudssus Social Software|https://raudss.us/>.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
